KeyLog that does exactly nothing.
Log the given secret. client_random is provided for
session identification. label describes precisely what
secret means: Read more
Indicates whether the secret with label label will be logged. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.